==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/sche_main_digest.php <==
<?php
//==============================================================
// Program Name		: 塼ե졼ʬ
// File Name		: sche_main.php
//--------------------------------------------------------------
// Date             : 2002/02/13
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc");
require("sche_commonfunction.inc");		// 塼붦̴ؿ


// ɽ
define("DAY_FORM",   "DAY");	// ɽ
define("WEEK_FORM",  "WEE");	// ɽ
define("MONTH_FORM", "MON");	// ɽ


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start($PHP_SELF);
menu_change("sche_main.php", $JJ_USERNAME);

// եѥ᡼ʤк
if (!isset($hiduke))
	$hiduke = date("Y-m-d");

if (!isset($sel))
	$sel = 0;

if (isset($mst))
	$member_id = $mst;

if (!isset($member_id))
	$member_id = "";

$pg_list = array(
			"sche_private.php",
			"sche_guntchart.php",
			"sche_group.php",
			"sche_all.php",
			"sche_find.php",
			"sche_datatype_manage.php");

print("<html>\n");
print("<head>\n");
print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s\">\n", $JJ_CSS_ROOT . $JJ_CSS_NAME);
print("</head>\n");
print("<frameset cols=\"190,*\">\n");
printf("<frame src=\"sche_submenu.php?hiduke=%s&sel=%d&mst=%s\" name=\"submenu\">\n", $hiduke, $sel, $member_id);
printf("<frame src=\"%s?mode=%s&hi=%s&hiduke=%s&no=%s&schedule_id=%s&new_section_id=%s&member_id=%s&new_viewtype=%s\" name=\"content\">\n",
			 $pg_list[$sel], $mode, $hiduke, $hiduke, $schedule_id, $schedule_id, $new_section, $member_id, $new_viewtype);
print("</frameset>\n");
print("</html>\n");

?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/sche_main_digest.php <==
<?php
//==============================================================
// Program Name		: 塼ե졼ʬ
// File Name		: sche_main.php
//--------------------------------------------------------------
// Date             : 2002/02/13
// Author           : Satoshi Fujii
//--------------------------------------------------------------
// Note				: 
//                  : 
//--------------------------------------------------------------
// Rev.             : 
//                  : 
//==============================================================

require("jetjob.inc.php");
require("sche_commonfunction.inc");		// 塼붦̴ؿ


// ɽ
define("DAY_FORM",   "DAY");	// ɽ
define("WEEK_FORM",  "WEE");	// ɽ
define("MONTH_FORM", "MON");	// ɽ


//==============================================================
// Function Name    : Program_Start
//--------------------------------------------------------------
// Note		        : 
//                  :
//==============================================================

Login_Start($PHP_SELF);
menu_change("sche_main.php", $JJ_USERNAME);

// եѥ᡼ʤк
if (!isset($hiduke))
	$hiduke = date("Y-m-d");

if (!isset($sel))
	$sel = 0;

if (isset($mst))
	$member_id = $mst;

if (!isset($member_id))
	$member_id = "";

$pg_list = array(
			"sche_private.php",
			"sche_guntchart.php",
			"sche_group.php",
			"sche_all.php",
			"sche_find.php",
			"sche_datatype_manage.php");

print("<html>\n");
print("<head>\n");
print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
printf("<META http-equiv=\"Content-Type\" content=\"text/html;charset=%s\">\n", $JJ_OUTPUT_CHARSET);
printf("<LINK REL=\"STYLESHEET\" TYPE=\"text/css\" HREF=\"%s\">\n", $JJ_CSS_ROOT . $JJ_CSS_NAME);
print("</head>\n");
print("<frameset cols=\"190,*\">\n");
printf("<frame src=\"sche_submenu.php?hiduke=%s&sel=%d&mst=%s\" name=\"submenu\">\n", $hiduke, $sel, $member_id);
printf("<frame src=\"%s?mode=%s&hi=%s&hiduke=%s&no=%s&schedule_id=%s&new_section_id=%s&member_id=%s&new_viewtype=%s\" name=\"content\">\n",
			 $pg_list[$sel], $mode, $hiduke, $hiduke, $schedule_id, $schedule_id, $new_section, $member_id, $new_viewtype);
print("</frameset>\n");
print("</html>\n");

?>
